package
Version:
v0.0.0-...-2b4790d
Opens a new window with list of versions in this module.
Published: Oct 5, 2020
License: MIT
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Canvas interface {
SetColor(rgbColor uint32)
MoveTo(x, y int)
LineTo(x, y int)
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.